@@ -68,7 +68,7 @@ int main(int argc, char **argv) {
     goto beach;
   }
 
-  examples_common_process((aubio_process_func_t)process_block, process_print);
+  examples_common_process(process_block, process_print);
 
   del_aubio_pvoc (pv);
   del_cvec (fftgrain);
