@@ -1,9 +1,8 @@
 #! /usr/bin/env python
 
-from unittest import main
 from numpy.testing import TestCase, assert_equal, assert_almost_equal
 from aubio import fvec, digital_filter
-from .utils import array_from_text_file
+from utils import array_from_text_file
 
 class aubio_filter_test_case(TestCase):
 
@@ -94,4 +93,5 @@ class aubio_filter_wrong_params(TestCase):
             digital_filter(-1)
 
 if __name__ == '__main__':
+    from unittest import main
     main()
