@@ -31,10 +31,6 @@
 #include "spectral/dct.h"
 #include "spectral/mfcc.h"
 
-#ifdef HAVE_NOOPT
-#define HAVE_SLOW_DCT 1
-#endif
-
 /** Internal structure for mfcc object */
 
 struct _aubio_mfcc_t
@@ -45,12 +41,8 @@ struct _aubio_mfcc_t
   uint_t n_coefs;           /** number of coefficients (<= n_filters/2 +1) */
   aubio_filterbank_t *fb;   /** filter bank */
   fvec_t *in_dct;           /** input buffer for dct * [fb->n_filters] */
-#if defined(HAVE_SLOW_DCT)
-  fmat_t *dct_coeffs;       /** DCT transform n_filters * n_coeffs */
-#else
-  aubio_dct_t *dct;
-  fvec_t *output;
-#endif
+  aubio_dct_t *dct;         /** dct object */
+  fvec_t *output;           /** dct output */
   smpl_t scale;
 };
 
@@ -62,11 +54,15 @@ new_aubio_mfcc (uint_t win_s, uint_t n_filters, uint_t n_coefs,
 
   /* allocate space for mfcc object */
   aubio_mfcc_t *mfcc = AUBIO_NEW (aubio_mfcc_t);
-#if defined(HAVE_SLOW_DCT)
-  smpl_t scaling;
 
-  uint_t i, j;
-#endif
+  if ((sint_t)n_coefs <= 0) {
+    AUBIO_ERR("mfcc: n_coefs should be > 0, got %d\n", n_coefs);
+    goto failure;
+  }
+  if ((sint_t)samplerate <= 0) {
+    AUBIO_ERR("mfcc: samplerate should be > 0, got %d\n", samplerate);
+    goto failure;
+  }
 
   mfcc->win_s = win_s;
   mfcc->samplerate = samplerate;
@@ -75,6 +71,10 @@ new_aubio_mfcc (uint_t win_s, uint_t n_filters, uint_t n_coefs,
 
   /* filterbank allocation */
   mfcc->fb = new_aubio_filterbank (n_filters, mfcc->win_s);
+
+  if (!mfcc->fb)
+    goto failure;
+
   if (n_filters == 40)
     aubio_filterbank_set_mel_coeffs_slaney (mfcc->fb, samplerate);
   else
@@ -84,46 +84,32 @@ new_aubio_mfcc (uint_t win_s, uint_t n_filters, uint_t n_coefs,
   /* allocating buffers */
   mfcc->in_dct = new_fvec (n_filters);
 
-#if defined(HAVE_SLOW_DCT)
-  mfcc->dct_coeffs = new_fmat (n_coefs, n_filters);
-
-  /* compute DCT transform dct_coeffs[j][i] as
-     cos ( j * (i+.5) * PI / n_filters ) */
-  scaling = 1. / SQRT (n_filters / 2.);
-  for (i = 0; i < n_filters; i++) {
-    for (j = 0; j < n_coefs; j++) {
-      mfcc->dct_coeffs->data[j][i] =
-          scaling * COS (j * (i + 0.5) * PI / n_filters);
-    }
-    mfcc->dct_coeffs->data[0][i] *= SQRT (2.) / 2.;
-  }
-#else
   mfcc->dct = new_aubio_dct (n_filters);
   mfcc->output = new_fvec (n_filters);
-#endif
+
+  if (!mfcc->in_dct || !mfcc->dct || !mfcc->output)
+    goto failure;
 
   mfcc->scale = 1.;
 
   return mfcc;
+
+failure:
+  del_aubio_mfcc(mfcc);
+  return NULL;
 }
 
 void
 del_aubio_mfcc (aubio_mfcc_t * mf)
 {
-
-  /* delete filterbank */
-  del_aubio_filterbank (mf->fb);
-
-  /* delete buffers */
-  del_fvec (mf->in_dct);
-#if defined(HAVE_SLOW_DCT)
-  del_fmat (mf->dct_coeffs);
-#else
-  del_aubio_dct (mf->dct);
-  del_fvec (mf->output);
-#endif
-
-  /* delete mfcc object */
+  if (mf->fb)
+    del_aubio_filterbank (mf->fb);
+  if (mf->in_dct)
+    del_fvec (mf->in_dct);
+  if (mf->dct)
+    del_aubio_dct (mf->dct);
+  if (mf->output)
+    del_fvec (mf->output);
   AUBIO_FREE (mf);
 }
 
@@ -131,9 +117,7 @@ del_aubio_mfcc (aubio_mfcc_t * mf)
 void
 aubio_mfcc_do (aubio_mfcc_t * mf, const cvec_t * in, fvec_t * out)
 {
-#ifndef HAVE_SLOW_DCT
   fvec_t tmp;
-#endif
 
   /* compute filterbank */
   aubio_filterbank_do (mf->fb, in, mf->in_dct);
@@ -144,16 +128,12 @@ aubio_mfcc_do (aubio_mfcc_t * mf, const cvec_t * in, fvec_t * out)
   if (mf->scale != 1) fvec_mul (mf->in_dct, mf->scale);
 
   /* compute mfccs */
-#if defined(HAVE_SLOW_DCT)
-  fmat_vecmul(mf->dct_coeffs, mf->in_dct, out);
-#else
   aubio_dct_do(mf->dct, mf->in_dct, mf->output);
   // copy only first n_coeffs elements
   // TODO assert mf->output->length == n_coeffs
   tmp.data = mf->output->data;
   tmp.length = out->length;
   fvec_copy(&tmp, out);
-#endif
 
   return;
 }
@@ -163,7 +143,7 @@ uint_t aubio_mfcc_set_power (aubio_mfcc_t *mf, smpl_t power)
   return aubio_filterbank_set_power(mf->fb, power);
 }
 
-uint_t aubio_mfcc_get_power (aubio_mfcc_t *mf)
+smpl_t aubio_mfcc_get_power (aubio_mfcc_t *mf)
 {
   return aubio_filterbank_get_power(mf->fb);
 }
@@ -174,7 +154,7 @@ uint_t aubio_mfcc_set_scale (aubio_mfcc_t *mf, smpl_t scale)
   return AUBIO_OK;
 }
 
-uint_t aubio_mfcc_get_scale (aubio_mfcc_t *mf)
+smpl_t aubio_mfcc_get_scale (aubio_mfcc_t *mf)
 {
   return mf->scale;
 }
