@@ -2,28 +2,31 @@
 //  - replace all 'double' with 'smpl_t'
 //  - include "aubio_priv.h" (for config.h and types.h)
 //  - add missing prototypes
-//  - use COS and SIN macros
+//  - use COS, SIN, and ATAN macros
+//  - add cast to (smpl_t) to avoid float conversion warnings
+//  - declare initialization as static
+//  - prefix public function with aubio_ooura_
 
 #include "aubio_priv.h"
 
-void cdft(int n, int isgn, smpl_t *a, int *ip, smpl_t *w);
-void rdft(int n, int isgn, smpl_t *a, int *ip, smpl_t *w);
-void ddct(int n, int isgn, smpl_t *a, int *ip, smpl_t *w);
-void ddst(int n, int isgn, smpl_t *a, int *ip, smpl_t *w);
-void dfct(int n, smpl_t *a, smpl_t *t, int *ip, smpl_t *w);
-void dfst(int n, smpl_t *a, smpl_t *t, int *ip, smpl_t *w);
-void makewt(int nw, int *ip, smpl_t *w);
-void makect(int nc, int *ip, smpl_t *c);
-void bitrv2(int n, int *ip, smpl_t *a);
-void bitrv2conj(int n, int *ip, smpl_t *a);
-void cftfsub(int n, smpl_t *a, smpl_t *w);
-void cftbsub(int n, smpl_t *a, smpl_t *w);
-void cft1st(int n, smpl_t *a, smpl_t *w);
-void cftmdl(int n, int l, smpl_t *a, smpl_t *w);
-void rftfsub(int n, smpl_t *a, int nc, smpl_t *c);
-void rftbsub(int n, smpl_t *a, int nc, smpl_t *c);
-void dctsub(int n, smpl_t *a, int nc, smpl_t *c);
-void dstsub(int n, smpl_t *a, int nc, smpl_t *c);
+void aubio_ooura_cdft(int n, int isgn, smpl_t *a, int *ip, smpl_t *w);
+void aubio_ooura_rdft(int n, int isgn, smpl_t *a, int *ip, smpl_t *w);
+void aubio_ooura_ddct(int n, int isgn, smpl_t *a, int *ip, smpl_t *w);
+void aubio_ooura_ddst(int n, int isgn, smpl_t *a, int *ip, smpl_t *w);
+void aubio_ooura_dfct(int n, smpl_t *a, smpl_t *t, int *ip, smpl_t *w);
+void aubio_ooura_dfst(int n, smpl_t *a, smpl_t *t, int *ip, smpl_t *w);
+static void makewt(int nw, int *ip, smpl_t *w);
+static void makect(int nc, int *ip, smpl_t *c);
+static void bitrv2(int n, int *ip, smpl_t *a);
+static void bitrv2conj(int n, int *ip, smpl_t *a);
+static void cftfsub(int n, smpl_t *a, smpl_t *w);
+static void cftbsub(int n, smpl_t *a, smpl_t *w);
+static void cft1st(int n, smpl_t *a, smpl_t *w);
+static void cftmdl(int n, int l, smpl_t *a, smpl_t *w);
+static void rftfsub(int n, smpl_t *a, int nc, smpl_t *c);
+static void rftbsub(int n, smpl_t *a, int nc, smpl_t *c);
+static void dctsub(int n, smpl_t *a, int nc, smpl_t *c);
+static void dstsub(int n, smpl_t *a, int nc, smpl_t *c);
 
 /*
 Fast Fourier/Cosine/Sine Transform
@@ -302,7 +305,7 @@ Appendix :
 */
 
 
-void cdft(int n, int isgn, smpl_t *a, int *ip, smpl_t *w)
+void aubio_ooura_cdft(int n, int isgn, smpl_t *a, int *ip, smpl_t *w)
 {
     void makewt(int nw, int *ip, smpl_t *w);
     void bitrv2(int n, int *ip, smpl_t *a);
@@ -327,7 +330,7 @@ void cdft(int n, int isgn, smpl_t *a, int *ip, smpl_t *w)
 }
 
 
-void rdft(int n, int isgn, smpl_t *a, int *ip, smpl_t *w)
+void aubio_ooura_rdft(int n, int isgn, smpl_t *a, int *ip, smpl_t *w)
 {
     void makewt(int nw, int *ip, smpl_t *w);
     void makect(int nc, int *ip, smpl_t *c);
@@ -361,7 +364,7 @@ void rdft(int n, int isgn, smpl_t *a, int *ip, smpl_t *w)
         a[0] += a[1];
         a[1] = xi;
     } else {
-        a[1] = 0.5 * (a[0] - a[1]);
+        a[1] = (smpl_t)0.5 * (a[0] - a[1]);
         a[0] -= a[1];
         if (n > 4) {
             rftbsub(n, a, nc, w + nw);
@@ -374,7 +377,7 @@ void rdft(int n, int isgn, smpl_t *a, int *ip, smpl_t *w)
 }
 
 
-void ddct(int n, int isgn, smpl_t *a, int *ip, smpl_t *w)
+void aubio_ooura_ddct(int n, int isgn, smpl_t *a, int *ip, smpl_t *w)
 {
     void makewt(int nw, int *ip, smpl_t *w);
     void makect(int nc, int *ip, smpl_t *c);
@@ -433,7 +436,7 @@ void ddct(int n, int isgn, smpl_t *a, int *ip, smpl_t *w)
 }
 
 
-void ddst(int n, int isgn, smpl_t *a, int *ip, smpl_t *w)
+void aubio_ooura_ddst(int n, int isgn, smpl_t *a, int *ip, smpl_t *w)
 {
     void makewt(int nw, int *ip, smpl_t *w);
     void makect(int nc, int *ip, smpl_t *c);
@@ -492,7 +495,7 @@ void ddst(int n, int isgn, smpl_t *a, int *ip, smpl_t *w)
 }
 
 
-void dfct(int n, smpl_t *a, smpl_t *t, int *ip, smpl_t *w)
+void aubio_ooura_dfct(int n, smpl_t *a, smpl_t *t, int *ip, smpl_t *w)
 {
     void makewt(int nw, int *ip, smpl_t *w);
     void makect(int nc, int *ip, smpl_t *c);
@@ -588,7 +591,7 @@ void dfct(int n, smpl_t *a, smpl_t *t, int *ip, smpl_t *w)
 }
 
 
-void dfst(int n, smpl_t *a, smpl_t *t, int *ip, smpl_t *w)
+void aubio_ooura_dfst(int n, smpl_t *a, smpl_t *t, int *ip, smpl_t *w)
 {
     void makewt(int nw, int *ip, smpl_t *w);
     void makect(int nc, int *ip, smpl_t *c);
@@ -690,7 +693,7 @@ void makewt(int nw, int *ip, smpl_t *w)
     ip[1] = 1;
     if (nw > 2) {
         nwh = nw >> 1;
-        delta = atan(1.0) / nwh;
+        delta = ATAN(1.0) / nwh;
         w[0] = 1;
         w[1] = 0;
         w[nwh] = COS(delta * nwh);
@@ -724,12 +727,12 @@ void makect(int nc, int *ip, smpl_t *c)
     ip[1] = nc;
     if (nc > 1) {
         nch = nc >> 1;
-        delta = atan(1.0) / nch;
-        c[0] = cos(delta * nch);
-        c[nch] = 0.5 * c[0];
+        delta = ATAN(1.0) / nch;
+        c[0] = COS(delta * nch);
+        c[nch] = (smpl_t)0.5 * c[0];
         for (j = 1; j < nch; j++) {
-            c[j] = 0.5 * cos(delta * j);
-            c[nc - j] = 0.5 * sin(delta * j);
+            c[j] = (smpl_t)0.5 * COS(delta * j);
+            c[nc - j] = (smpl_t)0.5 * SIN(delta * j);
         }
     }
 }
@@ -1585,7 +1588,7 @@ void rftfsub(int n, smpl_t *a, int nc, smpl_t *c)
     for (j = 2; j < m; j += 2) {
         k = n - j;
         kk += ks;
-        wkr = 0.5 - c[nc - kk];
+        wkr = (smpl_t)0.5 - c[nc - kk];
         wki = c[kk];
         xr = a[j] - a[k];
         xi = a[j + 1] + a[k + 1];
@@ -1611,7 +1614,7 @@ void rftbsub(int n, smpl_t *a, int nc, smpl_t *c)
     for (j = 2; j < m; j += 2) {
         k = n - j;
         kk += ks;
-        wkr = 0.5 - c[nc - kk];
+        wkr = (smpl_t)0.5 - c[nc - kk];
         wki = c[kk];
         xr = a[j] - a[k];
         xi = a[j + 1] + a[k + 1];
