@@ -1,13 +1,15 @@
 #include <aubio.h>
 #include "utils_tests.h"
 
+int test_wrong_params(void);
+
 int main (int argc, char **argv)
 {
   uint_t err = 0;
   if (argc < 2) {
     err = 2;
-    PRINT_ERR("not enough arguments\n");
-    PRINT_MSG("read a wave file as a mono vector\n");
+    PRINT_WRN("no arguments, running tests\n");
+    err = test_wrong_params();
     PRINT_MSG("usage: %s <source_path> [samplerate] [hop_size]\n", argv[0]);
     return err;
   }
@@ -15,8 +17,8 @@ int main (int argc, char **argv)
   uint_t win_s = 1024; // window size
   uint_t hop_size = win_s / 4;
   uint_t n_frames = 0, read = 0;
-  if ( argc == 3 ) samplerate = atoi(argv[2]);
-  if ( argc == 4 ) hop_size = atoi(argv[3]);
+  if ( argc >= 3 ) samplerate = atoi(argv[2]);
+  if ( argc >= 4 ) hop_size = atoi(argv[3]);
 
   char_t *source_path = argv[1];
   aubio_source_t * source = new_aubio_source(source_path, samplerate, hop_size);
@@ -60,3 +62,36 @@ beach:
 
   return err;
 }
+
+int test_wrong_params(void)
+{
+  uint_t win_size = 1024;
+  uint_t hop_size = win_size / 2;
+  uint_t samplerate = 44100;
+  // hop_size < 1
+  if (new_aubio_onset("default", 5, 0, samplerate)) return 1;
+
+  // buf_size < 2
+  if (new_aubio_onset("default", 1, 1, samplerate)) return 1;
+
+  // buf_size < hop_size
+  if (new_aubio_onset("default", hop_size, win_size, samplerate)) return 1;
+
+  // samplerate < 1
+  if (new_aubio_onset("default", 1024, 512, 0)) return 1;
+
+  // specdesc creation failed
+  if (new_aubio_onset("abcd", win_size, win_size/2, samplerate)) return 1;
+
+  aubio_onset_t *o;
+
+  // pv creation might fail
+  o = new_aubio_onset("default", 5, 2, samplerate);
+  if (o) del_aubio_onset(o);
+
+  o = new_aubio_onset("default", win_size, hop_size, samplerate);
+  if (!aubio_onset_set_default_parameters(o, "wrong_type")) return 1;
+  del_aubio_onset(o);
+
+  return run_on_default_source(main);
+}
