@@ -2,7 +2,7 @@
 
 #include <aubio.h>
 
-int main ()
+int main (void)
 {
   uint_t win_s = 1024; // window size
   fvec_t * in = new_fvec (win_s); // input buffer
