@@ -5,7 +5,7 @@
 
 #include <aubio.h>
 
-int main ()
+int main (void)
 {
   uint_t n = 10; // compute n times
   uint_t win_s = 1024; // window size
