@@ -3,7 +3,7 @@
 #include <aubio.h>
 #include <stdio.h>
 
-int main ()
+int main (void)
 {
   uint_t i = 0;
   uint_t win_s = 1024; // window size
